==> firebase_repository-1.0.59.tar.gz: lib/src/models/movrodeo.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:meta/meta.dart';

@immutable
class Movrodeo {
  final String uuid;
  final int cabezas;
  final String concepto;
  final int desbaste;
  final String detalle;
  final String destino;
  final DateTime fecha;
  final int kilos;
  final int precio;
  final String tropaUuid;

  Movrodeo(
      {this.uuid,
      this.cabezas,
      this.concepto,
      this.desbaste,
      this.detalle,
      this.destino,
      this.fecha,
      this.kilos,
      this.precio,
      this.tropaUuid});

  Movrodeo copyWith(
      {String uuid,
      int cabezas,
      String concepto,
      int desbaste,
      String detalle,
      String destino,
      DateTime fecha,
      int kilos,
      int precio,
      String tropaUuid}) {
    return Movrodeo(
      uuid:  uuid ?? this.uuid,
      cabezas: cabezas ?? this.cabezas,
      concepto: concepto ?? this.concepto,
      desbaste: desbaste ?? this.desbaste,
      detalle: detalle ?? this.detalle,
      destino: destino ?? this.destino,
      fecha: fecha ?? this.fecha,
      kilos: kilos ?? this.kilos,
      precio: precio ?? this.precio,
      tropaUuid: tropaUuid ?? this.tropaUuid
    );
  }

  @override
  String toString() {
    return 'Movrodeo{uuid: $uuid, cabezas: $cabezas, concepto: $concepto, desbaste: $desbaste, detalle: $detalle, destino: $destino, fecha: $fecha, kilos: $kilos, precio: $precio, tropaUuid: $tropaUuid}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Movrodeo &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              cabezas == other.cabezas &&
              concepto == other.concepto &&
              desbaste == other.desbaste &&
              detalle == other.detalle &&
              destino == other.destino &&
              fecha == other.fecha &&
              kilos == other.kilos &&
              precio == other.precio &&
              tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      uuid.hashCode ^
      cabezas.hashCode ^
      concepto.hashCode ^
      desbaste.hashCode ^
      detalle.hashCode ^
      destino.hashCode ^
      fecha.hashCode ^
      kilos.hashCode ^
      precio.hashCode ^
      tropaUuid.hashCode;

  MovrodeoEntity toEntity(){
    return MovrodeoEntity(
        uuid, cabezas, concepto, desbaste, detalle, destino, fecha, kilos, precio, tropaUuid);
  }

  static Movrodeo fromEntity(MovrodeoEntity entity){
    return Movrodeo(
      uuid: entity.uuid,
      cabezas: entity.cabezas,
      concepto: entity.concepto,
      desbaste: entity.desbaste,
      detalle: entity.detalle,
      destino: entity.destino,
      fecha: entity.fecha,
      kilos: entity.kilos,
      precio: entity.precio,
      tropaUuid: entity.tropaUuid
    );
  }
}

==> firebase_repository-1.1.24.tar.gz: lib/src/models/movrodeo.dart <==
import 'package:firebase_repository/src/entities/entities.dart';
import 'package:meta/meta.dart';

@immutable
class Movrodeo {
  final String uuid;
  final int cabezas;
  final String concepto;
  final double desbaste;
  final String detalle;
  final String destino;
  final String origen;
  final DateTime fecha;
  final double kilos;
  final double precio;
  final String tropaUuid;

  Movrodeo(
      {this.uuid,
      this.cabezas,
      this.concepto,
      this.desbaste,
      this.detalle,
      this.destino,
        this.origen,
      this.fecha,
      this.kilos,
      this.precio,
      this.tropaUuid});

  Movrodeo copyWith(
      {String uuid,
      int cabezas,
      String concepto,
      double desbaste,
      String detalle,
      String destino,
        String origen,
      DateTime fecha,
      double kilos,
      double precio,
      String tropaUuid}) {
    return Movrodeo(
      uuid:  uuid ?? this.uuid,
      cabezas: cabezas ?? this.cabezas,
      concepto: concepto ?? this.concepto,
      desbaste: desbaste ?? this.desbaste,
      detalle: detalle ?? this.detalle,
      destino: destino ?? this.destino,
      origen: origen ?? this.origen,
      fecha: fecha ?? this.fecha,
      kilos: kilos ?? this.kilos,
      precio: precio ?? this.precio,
      tropaUuid: tropaUuid ?? this.tropaUuid
    );
  }


  @override
  String toString() {
    return 'Movrodeo{uuid: $uuid, cabezas: $cabezas, concepto: $concepto, desbaste: $desbaste, detalle: $detalle, destino: $destino, origen: $origen, fecha: $fecha, kilos: $kilos, precio: $precio, tropaUuid: $tropaUuid}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Movrodeo &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              cabezas == other.cabezas &&
              concepto == other.concepto &&
              desbaste == other.desbaste &&
              detalle == other.detalle &&
              destino == other.destino &&
              origen == other.origen &&
              fecha == other.fecha &&
              kilos == other.kilos &&
              precio == other.precio &&
              tropaUuid == other.tropaUuid;

  @override
  int get hashCode =>
      uuid.hashCode ^
      cabezas.hashCode ^
      concepto.hashCode ^
      desbaste.hashCode ^
      detalle.hashCode ^
      destino.hashCode ^
      origen.hashCode ^
      fecha.hashCode ^
      kilos.hashCode ^
      precio.hashCode ^
      tropaUuid.hashCode;

  MovrodeoEntity toEntity(){
    return MovrodeoEntity(
        uuid, cabezas, concepto, desbaste, detalle, destino, origen, fecha, kilos, precio, tropaUuid);
  }

  static Movrodeo fromEntity(MovrodeoEntity entity){
    return Movrodeo(
      uuid: entity.uuid,
      cabezas: entity.cabezas,
      concepto: entity.concepto,
      desbaste: entity.desbaste,
      detalle: entity.detalle,
      destino: entity.destino,
      origen: entity.origen,
      fecha: entity.fecha,
      kilos: entity.kilos,
      precio: entity.precio,
      tropaUuid: entity.tropaUuid
    );
  }
}
